/* === Science & Technology Consultants (SciTeX) = Fri-04-07-2006 === */

/* --- Parameters --------------------------------------------------- */

Include "Test-2D.par";

/* --- Groups ------------------------------------------------------- */

Group {
/* ... Volume ....................................................... */

  VolDskA = Region[6001]; // Disk A
  VolDskB = Region[6002]; // Disk B

/* ... Surface ...................................................... */

  SfcBtmA = Region[5001]; // Bottom A
  SfcSdeA = Region[5002]; // Side A
  SfcTopA = Region[5003]; // Top A
  SfcBtmB = Region[5004]; // Bottom B
  SfcSdeB = Region[5005]; // Side B
  SfcTopB = Region[5006]; // Top B

/* ... Domain ....................................................... */

  VolA = Region[VolDskA] ;
  VolB = Region[VolDskB] ;
  SfcA = Region[{SfcBtmA,SfcSdeA}] ;
  SfcB = Region[{SfcSdeB,SfcTopB}] ;
  IfcA = Region[SfcTopA];
  IfcB = Region[SfcBtmB];

  DmnA = Region[{IfcA,SfcA,VolA}];
  DmnB = Region[{IfcB,SfcB,VolB}];
  Dmn = Region[{IfcA,IfcB,SfcA,SfcB,VolA,VolB}];
}

/* --- Functions ---------------------------------------------------- */

Function {
/* ... Time ......................................................... */

  TmeFct[] = ($Time < 1.0) ? 0.0 : 1.0;

/* ... Save ......................................................... */

  SveFct[] = !($TimeStep % 1);

/* ... Volume Properties ............................................ */

  MasDen[VolDskA] = 2330.0;
  HeaCap[VolDskA] =  507.0;
  TheCon[VolDskA] =  148.0;

  MasDen[VolDskB] = 2330.0;
  HeaCap[VolDskB] =  507.0;
  TheCon[VolDskB] =  148.0;

/* ... Volume Drivers ............................................... */

  HeaPwr[VolDskA] = 0.0;

  HeaPwr[VolDskB] = 0.0;

/* ... Surface Drivers .............................................. */

  HeaFlx[SfcBtmA] = 0.0;
  HeaFlx[SfcSdeA] = 0.0;

  HeaFlx[SfcSdeB] = 0.0;
  HeaFlx[SfcTopB] = Flx * (1.0 - (X[]/Rds)^2);

/* ... Surface Convection ........................................... */

  HTCCvn[SfcBtmA] = 10.0;
  TmpCvn[SfcBtmA] = TmpIni;
  HTCCvn[SfcSdeA] = 10.0;
  TmpCvn[SfcSdeA] = TmpIni;

  HTCCvn[SfcSdeB] = 10.0;
  TmpCvn[SfcSdeB] = TmpIni;
  HTCCvn[SfcTopB] = 10.0;
  TmpCvn[SfcTopB] = TmpIni;

/* ... Surface Radiation ............................................ */

  HTCRdn[SfcBtmA]   = 1.0*0.00*5.67051e-08;
  TmpRdn[SfcBtmA]   = TmpIni;
  HTCRdn[SfcSdeA]   = 1.0*0.00*5.67051e-08;
  TmpRdn[SfcSdeA]   = TmpIni;

  HTCRdn[SfcSdeB]   = 1.0*0.00*5.67051e-08;
  TmpRdn[SfcSdeB]   = TmpIni;
  HTCRdn[SfcTopB]   = 1.0*0.00*5.67051e-08;
  TmpRdn[SfcTopB]   = TmpIni;

/* ... Interface Transport .......................................... */

  HTCIfc[SfcTopA] = 1000.0;
  HTCIfc[SfcBtmB] = 1000.0;
}

/* --- Constraint --------------------------------------------------- */

Constraint {
  {Name ConA;
    Case {
      {Region DmnA; Type Init; Value TmpIni;}
    }
  }
  {Name ConB;
    Case {
      {Region DmnB; Type Init; Value TmpIni;}
    }
  }
}

/* --- General Thermal Problem Solver ------------------------------- */

Include "Test-2D.sol";

/* --- Post Operation ----------------------------------------------- */

PostOperation {
  {Name OpnA; NameOfPostProcessing PrcA;
    Operation {
      Print[TmpAA,OnElementsOf DmnA, File "TmpA-3D.pos"];
      Print[FlxAA,OnLine { {0.0,0.0    ,0.0} {Rds,0.0    ,0.0} } {25}, File "FlxA-2D_Btm.pos"];
      Print[FlxAA,OnLine { {Rds,0.0    ,0.0} {Rds,Hgt    ,0.0} } {25}, File "FlxA-2D_Sde.pos"];
      Print[FlxAA,OnLine { {0.0,Hgt    ,0.0} {Rds,Hgt    ,0.0} } {25}, File "FlxA-2D_Top.pos"];
    }
  }    
   
  {Name OpnB; NameOfPostProcessing PrcB;
    Operation {
      Print[TmpBB,OnElementsOf DmnB, File "TmpB-3D.pos"];
      Print[FlxBB,OnLine { {0.0,    Hgt+Sep,0.0} {Rds,    Hgt+Sep,0.0} } {25}, File "FlxB-2D_Btm.pos"];
      Print[FlxBB,OnLine { {Rds,    Hgt+Sep,0.0} {Rds,2.0*Hgt+Sep,0.0} } {25}, File "FlxB-2D_Sde.pos"];
      Print[FlxBB,OnLine { {0.0,2.0*Hgt+Sep,0.0} {Rds,2.0*Hgt+Sep,0.0} } {25}, File "FlxB-2D_Top.pos"];
    }
  }    
}

/* ================================================================== */

