/* === Science & Technology Consultants (SciTeX) = Fri-03-10-3006 === */

/* --- Jacobian (Axisymmetric 2D) ----------------------------------- */

Jacobian {
  {Name Jac;
    Case {
      {Region VolA;  Jacobian VolAxi;}
      {Region VolB;  Jacobian VolAxi;}
      {Region SfcA;  Jacobian SurAxi;}
      {Region SfcB;  Jacobian SurAxi;}
      {Region IfcA;  Jacobian SurAxi;}
      {Region IfcB;  Jacobian SurAxi;}
    }
  }
}

/* --- Integration -------------------------------------------------- */

Integration {
  {Name Int;
    Case {
      {Type Gauss;
        Case {
          { GeoElement Point      ; NumberOfPoints  1;}
          { GeoElement Line       ; NumberOfPoints  3;}
          { GeoElement Triangle   ; NumberOfPoints  4;}
          { GeoElement Quadrangle ; NumberOfPoints  4;}
          { GeoElement Tetrahedron; NumberOfPoints  4;}
          { GeoElement Hexahedron ; NumberOfPoints  6;}
          { GeoElement Prism      ; NumberOfPoints  6;}
        }
      }
    }
  }
}

/* --- Function Space ----------------------------------------------- */

FunctionSpace {
  {Name FctSpcA; Type Form0;
    BasisFunction {
      {Name TmpFctA; NameOfCoef TmpCofA; Function BF_Node; Support DmnA; Entity NodesOf[All];}
    }
    Constraint {
      {NameOfCoef TmpCofA; EntityType NodesOf; NameOfConstraint ConA;}
    }
  }

  {Name FctSpcB; Type Form0;
    BasisFunction {
      {Name TmpFctB; NameOfCoef TmpCofB; Function BF_Node; Support DmnB; Entity NodesOf[All];}
    }
    Constraint {
      {NameOfCoef TmpCofB; EntityType NodesOf; NameOfConstraint ConB;}
    }
  }
}

/* --- Formulation -------------------------------------------------- */

Formulation {
  {Name FrmA; Type FemEquation;
    Quantity {
      {Name TmpA; Type Local; NameOfSpace FctSpcA;}
      {Name TmpB; Type Local; NameOfSpace FctSpcB;}
      {Name TmpAveB; Type Integral; [{TmpB}/Rds]; In SfcBtmB; Integration Int; Jacobian Jac;}
    }

    Equation {
      Galerkin {Dt [MasDen[{TmpA}] * HeaCap[{TmpA}] * Dof{TmpA}, {TmpA}]; 
                In VolA; Integration Int; Jacobian Jac;}

      Galerkin {[TheCon[{TmpA}] * Dof{d TmpA}, {d TmpA}];
                In VolA; Integration Int; Jacobian Jac;}

      Galerkin {[-HeaPwr[], {TmpA}];
                In VolA; Integration Int; Jacobian Jac;}

      Galerkin {[-HeaFlx[], {TmpA}];
                In SfcA; Integration Int; Jacobian Jac;}

      Galerkin {[ HTCCvn[{TmpA}] * Dof{TmpA}, {TmpA}];
                In SfcA; Integration Int; Jacobian Jac;}

      Galerkin {[-HTCCvn[{TmpA}] * TmpCvn[], {TmpA}];
                In SfcA; Integration Int; Jacobian Jac;}

      Galerkin {[ HTCRdn[{TmpA}] * ({TmpA})^4, {TmpA}];
                In SfcA; Integration Int; Jacobian Jac;}

      Galerkin {[-HTCRdn[{TmpA}] * (TmpRdn[])^4, {TmpA}];
                In SfcA; Integration Int; Jacobian Jac;}

      Galerkin {[ HTCIfc[] * Dof{TmpA}, {TmpA}];
                In IfcA; Integration Int; Jacobian Jac;}

      Galerkin {[-HTCIfc[] * {TmpAveB}, {TmpA}];
                In IfcA; Integration Int; Jacobian Jac;}
    }
  }

  {Name FrmB; Type FemEquation;
    Quantity {
      {Name TmpA; Type Local; NameOfSpace FctSpcA;}
      {Name TmpB; Type Local; NameOfSpace FctSpcB;}
      {Name TmpAveA; Type Integral; [{TmpA}/Rds]; In SfcTopA; Integration Int; Jacobian Jac;}
    }

    Equation {
      Galerkin {Dt [MasDen[{TmpB}] * HeaCap[{TmpB}] * Dof{TmpB}, {TmpB}]; 
                In VolB; Integration Int; Jacobian Jac;}

      Galerkin {[TheCon[{TmpB}] * Dof{d TmpB}, {d TmpB}];
                In VolB; Integration Int; Jacobian Jac;}

      Galerkin {[-HeaPwr[], {TmpB}];
                In VolB; Integration Int; Jacobian Jac;}

      Galerkin {[-HeaFlx[], {TmpB}];
                In SfcB; Integration Int; Jacobian Jac;}

      Galerkin {[ HTCCvn[{TmpB}] * Dof{TmpB}, {TmpB}];
                In SfcB; Integration Int; Jacobian Jac;}

      Galerkin {[-HTCCvn[{TmpB}] * TmpCvn[], {TmpB}];
                In SfcB; Integration Int; Jacobian Jac;}

      Galerkin {[ HTCRdn[{TmpB}] * ({TmpB})^4, {TmpB}];
                In SfcB; Integration Int; Jacobian Jac;}

      Galerkin {[-HTCRdn[{TmpB}] * (TmpRdn[])^4, {TmpB}];
                In SfcB; Integration Int; Jacobian Jac;}

      Galerkin {[ HTCIfc[] * Dof{TmpB}, {TmpB}];
                In IfcB; Integration Int; Jacobian Jac;}

      Galerkin {[-HTCIfc[] * {TmpAveA}, {TmpB}];
                In IfcB; Integration Int; Jacobian Jac;}
    }
  }
}

/* --- Resolution --------------------------------------------------- */

Resolution {
  {Name Res;
    System {
      {Name SysA; NameOfFormulation FrmA;}
      {Name SysB; NameOfFormulation FrmB;}
    }
    Operation {
      InitSolution SysA;
      InitSolution SysB;
      SaveSolution SysA;
      SaveSolution SysB;
      TimeLoopTheta {
        Time0 TmeZro; TimeMax TmeDrn; DTime TmeStp; Theta 1.0;
        Operation {
          IterativeLoop[NonLinCnt,NonLinEps,NonLinRlx] {
            GenerateJac SysA;
            GenerateJac SysB;
            SolveJac SysA;
            SolveJac SysB;
          }
          SaveSolution SysA;
          SaveSolution SysB;
        }
      }
    }
  }

  {Name ResSS;
    System {
      {Name SysA; NameOfFormulation FrmA;}
      {Name SysB; NameOfFormulation FrmB;}
    }
    Operation {
      InitSolution SysA;
      InitSolution SysB;
      IterativeLoop[NonLinCnt,NonLinEps,NonLinRlx] {
        GenerateJac SysA;
        GenerateJac SysB;
        SolveJac SysA;
        SolveJac SysB;
      }
      SaveSolution SysA;
      SaveSolution SysB;
    }
  }
}

/* --- Post Processing ---------------------------------------------- */

PostProcessing {
  {Name PrcA; NameOfFormulation FrmA;
    Quantity {
      {Name TmpAA; Value{Local{[{TmpA}]                       ; In VolA; Jacobian Jac;}}}
      {Name FlxAA; Value{Local{[-TheCon[{TmpA}] * {Grad TmpA}]; In VolA; Jacobian Jac;}}}
    }
  }

  {Name PrcB; NameOfFormulation FrmB;
    Quantity {
      {Name TmpBB; Value{Local{[{TmpB}]                       ; In VolB; Jacobian Jac;}}}
      {Name FlxBB; Value{Local{[-TheCon[{TmpB}] * {Grad TmpB}]; In VolB; Jacobian Jac;}}}
    }
  }
}

/* ================================================================== */

